/*
 * BondInfo.hpp
 *
 *  Created on: Apr 5, 2012
 *      Author: heber
 */

#ifndef BONDINFO_HPP_
#define BONDINFO_HPP_


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "types.hpp"
#include "Bond/bond.hpp"


/** Structure for containing bond state information.
 *
 * This is used for re-creating bonds during undo/redo of Action's.
 *
 */
struct BondInfo {
  /** Constructor that takes state information from \a _bond.
   *
   * @param _bond bond whose state to store
   */
  BondInfo(const bond::ptr _bond);

  /** Recreates the bond whose state is contained in this BondInfo.
   *
   * @return true - bond created, false - bond already exists
   */
  bool RecreateBond() const;

  /** Removes the bond whose state is contained in this BondInfo.
   *
   */
  void RemoveBond() const;

  //!> id of left bond partner
  atomId_t leftid;

  //!> id of right bond partner
  atomId_t rightid;

  //!> bond degree
  size_t degree;
};



#endif /* BONDINFO_HPP_ */
